# Linear Encoder

::: linax.encoder.linear.LinearEncoderConfig
    options:
      members:
        - build

---

::: linax.encoder.linear.LinearEncoder
    options:
      members:
        - __init__
        - __call__
